@@ -120,6 +120,16 @@ Author: w.x.chan@gmail.com    15Oct2020                - v2.7.12
 						-BsplineFourier version 2.7.12
 						-motionCorrect version 2.7.8
 						-segment verion 2.7.9
+Author: w.x.chan@gmail.com    07Nov2020                - v2.7.13
+						-bfSolver version 2.7.11
+						-BsplineFourier version 2.7.13
+						-motionCorrect version 2.7.8
+						-segment verion 2.7.9
+Author: w.x.chan@gmail.com    20Jan2021                - v2.7.14
+						-bfSolver version 2.7.14
+						-BsplineFourier version 2.7.14
+						-motionCorrect version 2.7.8
+						-segment verion 2.7.14
 
 Requirements:
     autoD
@@ -134,7 +144,7 @@ Known Bug:
     HSV color format not supported
 All rights reserved.
 '''
-_version='2.7.12'
+_version='2.7.14'
 import logging
 logger = logging.getLogger('motionSegmentation v'+_version)
 logger.info('motionSegmentation version '+_version)
