@@ -21,6 +21,10 @@ History:
   Author: jorry.zhengyu@gmail.com    03June2020           - v2.7.11
                                                              -add NFFT initialization to estimateInitialwithRefTime
                                                              -add delimiter option to pointTrace
+  Author: w.x.chan@gmail.com         19Jan2021           - v2.7.14
+                                                             -remove Bspline2D in addBsplineFile function (bug)
+                                                             -debug refTimeStep option in estimateInitialwithRefTime
+                                                             -auto detect timeMapList in estimateInitialwithRefTime
 
 Requirements:
     BsplineFourier
@@ -32,7 +36,7 @@ Known Bug:
     None
 All rights reserved.
 '''
-_version='2.7.11'
+_version='2.7.14'
 
 import logging
 logger = logging.getLogger(__name__)
@@ -212,10 +216,7 @@ class bfSolver:
                 self.weights.append(1.)
             else:
                 self.weights.append(weightList[n])
-            if twoD:
-                self.bsplines.append(BsplineFourier.Bspline2D(coefFile=BsplineFileList[n],shape=None,timeMap=timeMapList[n],spacing=None,fileScale=fileScale,delimiter=' ',origin=None))
-            else:
-                self.bsplines.append(BsplineFourier.Bspline(coefFile=BsplineFileList[n],shape=None,timeMap=timeMapList[n],spacing=None,fileScale=fileScale,delimiter=' ',origin=None))
+            self.bsplines.append(BsplineFourier.Bspline(coefFile=BsplineFileList[n],shape=None,timeMap=timeMapList[n],spacing=None,fileScale=fileScale,delimiter=' ',origin=None))
     def addImgVecFile(self,imgVecFileList=None,timeMapList=None,weightList=None,fileScale=1.):
         ''' 
         add (multiple) BspineFile to solver
@@ -1354,16 +1355,14 @@ class bfSolver:
         return newImg
                     
         
-    def estimateInitialwithRefTime(self,OrderedBsplinesList,tRef=None,refTimeStep=0,OrderedBsplinesList2=None,spacingDivision=2.,gap=0,forwardbackward=False,timeMapList=None,N=20):
+    def estimateInitialwithRefTime(self,OrderedBsplinesList,tRef=None,OrderedBsplinesList2=None,spacingDivision=2.,gap=0,forwardbackward=False,N=20):
         ''' 
         Estimates bsplineFourier with forward marching
         Parameters:
             OrderedBsplinesList: List(int)
                 List of index in self.bsplines to use as tref to tn marching
-            refTimeStep:int
-                identify the reference time step tref in OrderedBsplinesList
             OrderedBsplinesList2: List(int)
-                List of index in self.bsplines to use as tn-1 to tn marching
+                List of index in self.bsplines to use as tn-1 to tn marching starting from tref to tref+1
             spacingDivision:float
                 sampling points density between bsplineFourier grid
             gap:int
@@ -1374,7 +1373,26 @@ class bfSolver:
         '''
         if type(OrderedBsplinesList)==int:
             OrderedBsplinesList=range(OrderedBsplinesList)
-        if type(timeMapList)!=type(None):
+        if self.bsplines[OrderedBsplinesList[0]].timeMap[0] is None:
+            timeMapList=None
+            logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', 'str(self.bsplines[OrderedBsplinesList[0]].timeMap)+'.')
+        else:
+            timeMapList=[self.bsplines[OrderedBsplinesList[0]].timeMap[0]]
+            for n in range(len(OrderedBsplinesList)):
+                if self.bsplines[OrderedBsplinesList[n]].timeMap[1] is None:
+                    timeMapList=None
+                    logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', 'str(self.bsplines[OrderedBsplinesList[n]].timeMap)+'.')
+                    break
+                else:
+                    timeMapList.append(self.bsplines[OrderedBsplinesList[n]].timeMap[1])
+            else:
+                timeMapList=np.array(timeMapList)
+                for n in range(len(timeMapList)):
+                    while timeMapList[n]>=self.bsFourier.spacing[-1]:
+                        timeMapList[n]-=self.bsFourier.spacing[-1]
+                    while timeMapList[n]<0:
+                        timeMapList[n]+=self.bsFourier.spacing[-1]
+        if timeMapList is not None:
             locate_coordsThruTime = timeMapList/self.bsFourier.spacing[-1] - 0.5
             weight=[]
             weight.append(1)
@@ -1397,17 +1415,12 @@ class bfSolver:
                 coordsThruTime=Fratio.reshape((-1,1))*coordsThruTime+(1-Fratio.reshape((-1,1)))*coordsThruTime2
             else:
                 coordsThruTime=estCoordsThruTime(coord,self.bsplines,OrderedBsplinesList,OrderedBsplinesList2=OrderedBsplinesList2,mode='Lagrangian-Eulerian')
-            if refTimeStep!=0:
-                tempcoordsThruTime=coordsThruTime.copy()
-                tempcoordsThruTime[:refTimeStep]=coordsThruTime[-refTimeStep:]
-                tempcoordsThruTime[refTimeStep:]=coordsThruTime[:-refTimeStep]
-                coordsThruTime=tempcoordsThruTime.copy()
             coordsThruTime=np.array(coordsThruTime)
             #deltat=self.bsplines[0].timeMap[1]-self.bsplines[0].timeMap[0]
             #freq=np.fft.rfftfreq(len(coordsThruTime[:,0]))*2.*np.pi/deltat
             sampleCoeftemp=[]
             for axis in range(self.points.shape[-1]):
-                if type(timeMapList)!=type(None):
+                if timeMapList is not None:
                     sp = nfft.nfft_adjoint(locate_coordsThruTime, coordsThruTime[:,axis], N)
                     sampleCoeftemp.append(np.array([sp.real[int(N/2)]/len(coordsThruTime),*(sp.real[int(N/2+1):int(self.bsFourier.coef.shape[self.points.shape[-1]]/2+N/2+1)]/len(coordsThruTime)*2.),*(-sp.imag[int(N/2+1):int(self.bsFourier.coef.shape[self.points.shape[-1]]/2+N/2+1)]/len(coordsThruTime)*2.)])*np.array(weight))                  
                 else:
